@@ -2,11 +2,42 @@
 # this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 
-from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
+from trytond.model import ModelView, Workflow, fields
+from trytond.modules.product import round_price
+from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
-from trytond.modules.product import round_price
+
+class ShipmentIn(metaclass=PoolMeta):
+    __name__ = 'stock.shipment.in'
+
+    @classmethod
+    @ModelView.button
+    @Workflow.transition('received')
+    def receive(cls, shipments):
+        pool = Pool()
+        PurchaseLineComponent = pool.get('purchase.line.component')
+        for shipment in shipments:
+            for move in shipment.incoming_moves:
+                if isinstance(move.origin, PurchaseLineComponent):
+                    move.origin.check_move_quantity()
+        super().receive(shipments)
+
+
+class ShipmentOutReturn(metaclass=PoolMeta):
+    __name__ = 'stock.shipment.out.return'
+
+    @classmethod
+    @ModelView.button
+    @Workflow.transition('received')
+    def receive(cls, shipments):
+        pool = Pool()
+        SaleLineComponent = pool.get('sale.line.component')
+        for shipment in shipments:
+            for move in shipment.incoming_moves:
+                if isinstance(move.origin, SaleLineComponent):
+                    move.origin.check_move_quantity()
+        super().receive(shipments)
 
 
 class Move(metaclass=PoolMeta):
@@ -29,7 +60,7 @@ class Move(metaclass=PoolMeta):
             unit_price = amount / Decimal(str(quantity))
         if unit_price is not None:
             unit_price = UoM.compute_price(
-                self.origin.unit, unit_price, self.uom)
+                self.origin.unit, unit_price, self.unit)
             unit_price = round_price(unit_price)
         return unit_price
 
@@ -51,13 +82,8 @@ class MoveSale(metaclass=PoolMeta):
 
     @classmethod
     def search_sale(cls, name, clause):
-        operator = clause[1]
-        if operator.startswith('!') or operator.startswith('not '):
-            bool_op = 'AND'
-        else:
-            bool_op = 'OR'
         domain = super().search_sale(name, clause)
-        return [bool_op,
+        return ['OR',
             domain,
             ('origin.line.' + clause[0],
                 *clause[1:3], 'sale.line.component', *clause[3:]),
@@ -84,7 +110,7 @@ class MoveSale(metaclass=PoolMeta):
         # Use getattr as reference field can have negative id
         if (isinstance(self.origin, SaleLineComponent)
                 and getattr(self.origin, 'unit', None)):
-            category = self.origin.unit.category.id
+            category = self.origin.unit.category
         return category
 
     def get_cost_price(self, product_cost_price=None):
@@ -149,13 +175,8 @@ class MovePurchase(metaclass=PoolMeta):
 
     @classmethod
     def search_purchase(cls, name, clause):
-        operator = clause[1]
-        if operator.startswith('!') or operator.startswith('not '):
-            bool_op = 'AND'
-        else:
-            bool_op = 'OR'
         domain = super().search_purchase(name, clause)
-        return [bool_op,
+        return ['OR',
             domain,
             ('origin.line.' + clause[0],
                 *clause[1:3], 'purchase.line.component', *clause[3:]),
@@ -171,13 +192,8 @@ class MovePurchase(metaclass=PoolMeta):
 
     @classmethod
     def search_supplier(cls, name, clause):
-        operator = clause[1]
-        if operator.startswith('!') or operator.startswith('not '):
-            bool_op = 'AND'
-        else:
-            bool_op = 'OR'
         domain = super().search_supplier(name, clause)
-        return [bool_op,
+        return ['OR',
             domain,
             ('origin.line.purchase.party' + clause[0][len(name):],
                 *clause[1:3], 'purchase.line.component', *clause[3:])]
@@ -203,7 +219,7 @@ class MovePurchase(metaclass=PoolMeta):
         # Use getattr as reference field can have negative id
         if (isinstance(self.origin, PurchaseLineComponent)
                 and getattr(self.origin, 'unit', None)):
-            category = self.origin.unit.category.id
+            category = self.origin.unit.category
         return category
 
     @property
